package betterquesting.api2.client.gui.panels.lists;

import betterquesting.api.utils.BigItemStack;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.panels.content.PanelItemSlot;
import betterquesting.api2.utils.QuestTranslation;
import betterquesting.core.BetterQuesting;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraftforge.oredict.OreDictionary;

/* loaded from: betterquesting_api2_client_gui_panels_lists.jar:betterquesting/api2/client/gui/panels/lists/CanvasItemDatabase.class */
public class CanvasItemDatabase extends CanvasSearch<ItemStack, Item> {
    private final int btnId;

    public CanvasItemDatabase(IGuiRect rect, int buttonId) {
        super(rect);
        this.btnId = buttonId;
    }

    @Override // betterquesting.api2.client.gui.panels.lists.CanvasSearch
    protected Iterator<Item> getIterator() {
        return Item.field_150901_e.iterator();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // betterquesting.api2.client.gui.panels.lists.CanvasSearch
    public void queryMatches(Item item, String query, ArrayDeque<ItemStack> results) {
        String regName;
        if (item == null || (regName = Item.field_150901_e.func_148750_c(item)) == null) {
            return;
        }
        try {
            List<ItemStack> subList = new ArrayList<>();
            item.func_150895_a(item, CreativeTabs.field_78027_g, subList);
            if (subList.isEmpty()) {
                subList.add(new ItemStack(item));
            }
            if (regName.toLowerCase().contains(query) || item.func_77658_a().toLowerCase().contains(query) || QuestTranslation.translate(item.func_77658_a(), new Object[0]).toLowerCase().contains(query)) {
                results.addAll(subList);
            } else {
                subList.parallelStream().forEach(subItem -> {
                    try {
                        if (subItem.func_77977_a().toLowerCase().contains(query) || subItem.func_82833_r().toLowerCase().contains(query)) {
                            results.add(subItem);
                        } else if (Arrays.stream(OreDictionary.getOreIDs(subItem)).anyMatch(id -> {
                            return OreDictionary.getOreName(id).toLowerCase().contains(query);
                        })) {
                            results.add(subItem);
                        }
                    } catch (Exception e) {
                        BetterQuesting.logger.error("An error occured while searching itemstack " + subItem.toString() + " from item \"" + regName + "\" (" + item.getClass().getName() + ").\nNBT: " + subItem.func_77955_b(new NBTTagCompound()), e);
                    }
                });
            }
        } catch (Exception e) {
            BetterQuesting.logger.error("An error occured while searching item \"" + regName + "\" (" + item.getClass().getName() + ")", e);
        }
    }

    @Override // betterquesting.api2.client.gui.panels.lists.CanvasSearch
    public boolean addResult(ItemStack stack, int index, int cachedWidth) {
        if (stack == null) {
            return false;
        }
        int x = (index % (cachedWidth / 18)) * 18;
        int y = (index / (cachedWidth / 18)) * 18;
        addPanel(new PanelItemSlot(new GuiRectangle(x, y, 18, 18, 0), this.btnId, new BigItemStack(stack)));
        return true;
    }
}
